import * as React from "react";
import {observer} from "mobx-react-lite";
import {ShiftModel} from "../../stores/ShiftStore";
import {ColorPicker} from 'material-ui-color';
import {Typography} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {HintButton} from "@rx-suite/ui";
import {isArrayLike} from "@rx-suite/data";

const useStyles = makeStyles(() => ({
    wrapper: {
        display: "flex",
        alignItems: 'center'
    }
}));

export const ShiftColorPicker: React.FunctionComponent<{ model: ShiftModel, readOnly?: boolean, includeLabel?: boolean, includeHint?: boolean }> = observer(({
                                                                                                                                                                 model,
                                                                                                                                                                 readOnly,
                                                                                                                                                                 includeLabel = true,
                                                                                                                                                                 includeHint = true
                                                                                                                                                             }) => {
        const classes = useStyles();
        const [workingColor, setWorkingColor] = React.useState(model.viewModel.color);
        React.useEffect(() => {
            setWorkingColor(model.viewModel.color);
        }, [setWorkingColor, model.viewModel.color])
        const handleColorChange = React.useCallback(newColor => {
            if (!readOnly) {
                if (newColor.error || (!(isArrayLike(newColor.raw) && (newColor.raw.length < 6)))) {
                    setWorkingColor(newColor.raw); // if the user types in a Hex code we need to allow partial entry.  If they click directly on the picker grid then raw will be an array of values that we can extract a complete hex from
                } else if (newColor.hex) {
                    const withHash = newColor.hex[0] === '#' ? newColor.hex : `#${newColor.hex}`
                    setWorkingColor(withHash)
                    model.nestedAssignment('color', withHash);
                }
            }
        }, [model, setWorkingColor, readOnly]);
        return (
            <div className={classes.wrapper}>
                {includeLabel && <Typography><Trans>Calendar Color</Trans></Typography>}
                <ColorPicker value={workingColor} onChange={handleColorChange} disableAlpha hideTextfield/>
                {includeHint && <HintButton title={model.label('color')} text={model.attributeDescription('color')}/>}
            </div>
        );
    }
);